==> plex-sync-0.2.4.tgz: package/lib/index.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _ui = require('./ui');

var _plex = require('./plex');

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

require('./env');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _updateNotifier2.default)({ pkg: _package2.default }).notify();

var DRY_RUN = !!process.env.DRY_RUN;
var FUZZY = (process.env.MATCH_TYPE || 'fuzzy') === 'fuzzy';

if (process.argv.length < 4) {
  (0, _ui.exitUsage)();
}

var servers = process.argv.slice(2).map(_ui.parseCLIArg);

(0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
  return _regenerator2.default.wrap(function _callee2$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.prev = 0;
          return _context3.delegateYield(_regenerator2.default.mark(function _callee() {
            var movies, watched, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, serverMovies, _iteratorNormalCompletion2, _didIteratorError2, _iteratorError2, _loop, _iterator2, _step2;

            return _regenerator2.default.wrap(function _callee$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    (0, _ui.log)('Reading data from ' + servers.map(function (server) {
                      return server.host;
                    }).join(', ') + '...');

                    _context2.next = 3;
                    return (0, _ui.progressMap)(servers, function (server) {
                      return (0, _plex.fetchMovies)(server, FUZZY);
                    });

                  case 3:
                    movies = _context2.sent;
                    watched = new _set2.default();
                    _iteratorNormalCompletion = true;
                    _didIteratorError = false;
                    _iteratorError = undefined;
                    _context2.prev = 8;


                    for (_iterator = (0, _getIterator3.default)(movies); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                      serverMovies = _step.value;

                      serverMovies.forEach(function (movie) {
                        if (movie.watched) watched.add(movie.guid);
                      });
                    }

                    _context2.next = 16;
                    break;

                  case 12:
                    _context2.prev = 12;
                    _context2.t0 = _context2['catch'](8);
                    _didIteratorError = true;
                    _iteratorError = _context2.t0;

                  case 16:
                    _context2.prev = 16;
                    _context2.prev = 17;

                    if (!_iteratorNormalCompletion && _iterator.return) {
                      _iterator.return();
                    }

                  case 19:
                    _context2.prev = 19;

                    if (!_didIteratorError) {
                      _context2.next = 22;
                      break;
                    }

                    throw _iteratorError;

                  case 22:
                    return _context2.finish(19);

                  case 23:
                    return _context2.finish(16);

                  case 24:
                    (0, _ui.log)('Syncing any unsynced media...');

                    _iteratorNormalCompletion2 = true;
                    _didIteratorError2 = false;
                    _iteratorError2 = undefined;
                    _context2.prev = 28;
                    _loop = _regenerator2.default.mark(function _loop() {
                      var _step2$value, idx, serverMovies, server, needsSync;

                      return _regenerator2.default.wrap(function _loop$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              _step2$value = (0, _slicedToArray3.default)(_step2.value, 2);
                              idx = _step2$value[0];
                              serverMovies = _step2$value[1];
                              server = servers[idx];
                              needsSync = serverMovies.filter(function (movie) {
                                return !movie.watched && watched.has(movie.guid);
                              });
                              _context.next = 7;
                              return (0, _ui.progressMap)(needsSync, function (media) {
                                if (DRY_RUN) {
                                  (0, _ui.log)('Dry run: marking ' + media.title + ' watched on ' + server.host);
                                  return;
                                }

                                (0, _plex.markWatched)(server, media);
                              });

                            case 7:
                            case 'end':
                              return _context.stop();
                          }
                        }
                      }, _loop, undefined);
                    });
                    _iterator2 = (0, _getIterator3.default)(movies.entries());

                  case 31:
                    if (_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done) {
                      _context2.next = 36;
                      break;
                    }

                    return _context2.delegateYield(_loop(), 't1', 33);

                  case 33:
                    _iteratorNormalCompletion2 = true;
                    _context2.next = 31;
                    break;

                  case 36:
                    _context2.next = 42;
                    break;

                  case 38:
                    _context2.prev = 38;
                    _context2.t2 = _context2['catch'](28);
                    _didIteratorError2 = true;
                    _iteratorError2 = _context2.t2;

                  case 42:
                    _context2.prev = 42;
                    _context2.prev = 43;

                    if (!_iteratorNormalCompletion2 && _iterator2.return) {
                      _iterator2.return();
                    }

                  case 45:
                    _context2.prev = 45;

                    if (!_didIteratorError2) {
                      _context2.next = 48;
                      break;
                    }

                    throw _iteratorError2;

                  case 48:
                    return _context2.finish(45);

                  case 49:
                    return _context2.finish(42);

                  case 50:

                    (0, _ui.log)('Sync completed!');

                  case 51:
                  case 'end':
                    return _context2.stop();
                }
              }
            }, _callee, undefined, [[8, 12, 16, 24], [17,, 19, 23], [28, 38, 42, 50], [43,, 45, 49]]);
          })(), 't0', 2);

        case 2:
          _context3.next = 7;
          break;

        case 4:
          _context3.prev = 4;
          _context3.t1 = _context3['catch'](0);

          (0, _ui.log)(_context3.t1.stack);

        case 7:
        case 'end':
          return _context3.stop();
      }
    }
  }, _callee2, undefined, [[0, 4]]);
}))();

==> plex-sync-0.3.0.tgz: package/lib/index.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _ui = require('./ui');

var _plex = require('./plex');

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

require('./env');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _updateNotifier2.default)({ pkg: _package2.default }).notify();

var DRY_RUN = !!process.env.DRY_RUN;
var FUZZY = (process.env.MATCH_TYPE || 'fuzzy') === 'fuzzy';

if (process.argv.length < 4) {
  (0, _ui.exitUsage)();
}

var servers = process.argv.slice(2).map(_ui.parseCLIArg);

(0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
  return _regenerator2.default.wrap(function _callee2$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.prev = 0;
          return _context3.delegateYield(_regenerator2.default.mark(function _callee() {
            var movies, watched, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, _step$value, idx, serverMovies, server, _iteratorNormalCompletion2, _didIteratorError2, _iteratorError2, _loop, _iterator2, _step2;

            return _regenerator2.default.wrap(function _callee$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    (0, _ui.log)('Reading data from ' + servers.map(function (server) {
                      return server.host;
                    }).join(', ') + '...');

                    _context2.next = 3;
                    return (0, _ui.progressMap)(servers, function (server) {
                      return (0, _plex.fetchMovies)(server, FUZZY);
                    });

                  case 3:
                    movies = _context2.sent;
                    watched = new _set2.default();
                    _iteratorNormalCompletion = true;
                    _didIteratorError = false;
                    _iteratorError = undefined;
                    _context2.prev = 8;


                    for (_iterator = (0, _getIterator3.default)(movies.entries()); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                      _step$value = (0, _slicedToArray3.default)(_step.value, 2);
                      idx = _step$value[0];
                      serverMovies = _step$value[1];
                      server = servers[idx];


                      if (server.mode.read) {
                        serverMovies.forEach(function (movie) {
                          if (movie.watched) watched.add(movie.guid);
                        });
                      }
                    }

                    _context2.next = 16;
                    break;

                  case 12:
                    _context2.prev = 12;
                    _context2.t0 = _context2['catch'](8);
                    _didIteratorError = true;
                    _iteratorError = _context2.t0;

                  case 16:
                    _context2.prev = 16;
                    _context2.prev = 17;

                    if (!_iteratorNormalCompletion && _iterator.return) {
                      _iterator.return();
                    }

                  case 19:
                    _context2.prev = 19;

                    if (!_didIteratorError) {
                      _context2.next = 22;
                      break;
                    }

                    throw _iteratorError;

                  case 22:
                    return _context2.finish(19);

                  case 23:
                    return _context2.finish(16);

                  case 24:
                    (0, _ui.log)('Syncing any unsynced media...');

                    _iteratorNormalCompletion2 = true;
                    _didIteratorError2 = false;
                    _iteratorError2 = undefined;
                    _context2.prev = 28;
                    _loop = _regenerator2.default.mark(function _loop() {
                      var _step2$value, idx, serverMovies, server, needsSync;

                      return _regenerator2.default.wrap(function _loop$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              _step2$value = (0, _slicedToArray3.default)(_step2.value, 2);
                              idx = _step2$value[0];
                              serverMovies = _step2$value[1];
                              server = servers[idx];

                              if (!server.mode.write) {
                                _context.next = 8;
                                break;
                              }

                              needsSync = serverMovies.filter(function (movie) {
                                return !movie.watched && watched.has(movie.guid);
                              });
                              _context.next = 8;
                              return (0, _ui.progressMap)(needsSync, function (media) {
                                if (DRY_RUN) {
                                  (0, _ui.log)('Dry run: marking ' + media.title + ' watched on ' + server.host);
                                  return;
                                }

                                (0, _plex.markWatched)(server, media);
                              });

                            case 8:
                            case 'end':
                              return _context.stop();
                          }
                        }
                      }, _loop, undefined);
                    });
                    _iterator2 = (0, _getIterator3.default)(movies.entries());

                  case 31:
                    if (_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done) {
                      _context2.next = 36;
                      break;
                    }

                    return _context2.delegateYield(_loop(), 't1', 33);

                  case 33:
                    _iteratorNormalCompletion2 = true;
                    _context2.next = 31;
                    break;

                  case 36:
                    _context2.next = 42;
                    break;

                  case 38:
                    _context2.prev = 38;
                    _context2.t2 = _context2['catch'](28);
                    _didIteratorError2 = true;
                    _iteratorError2 = _context2.t2;

                  case 42:
                    _context2.prev = 42;
                    _context2.prev = 43;

                    if (!_iteratorNormalCompletion2 && _iterator2.return) {
                      _iterator2.return();
                    }

                  case 45:
                    _context2.prev = 45;

                    if (!_didIteratorError2) {
                      _context2.next = 48;
                      break;
                    }

                    throw _iteratorError2;

                  case 48:
                    return _context2.finish(45);

                  case 49:
                    return _context2.finish(42);

                  case 50:

                    (0, _ui.log)('Sync completed!');

                  case 51:
                  case 'end':
                    return _context2.stop();
                }
              }
            }, _callee, undefined, [[8, 12, 16, 24], [17,, 19, 23], [28, 38, 42, 50], [43,, 45, 49]]);
          })(), 't0', 2);

        case 2:
          _context3.next = 7;
          break;

        case 4:
          _context3.prev = 4;
          _context3.t1 = _context3['catch'](0);

          (0, _ui.log)(_context3.t1.stack);

        case 7:
        case 'end':
          return _context3.stop();
      }
    }
  }, _callee2, undefined, [[0, 4]]);
}))();
